@@ -326,6 +326,7 @@ shinyServer(function(input, output, session) {
     paste(input$CalcBestModel, input$chosenTypePlotSubset)
   })
 
+
   wlPlot <- eventReactive(changeObject(), {
 
     cNORM::plotSubset(bestModel(), type = chosenTypeOfPlotSubset())
@@ -349,6 +350,19 @@ shinyServer(function(input, output, session) {
     }
   })
 
+
+  crossValidation <- eventReactive(input$CrossValidation, {
+    rep <- input$RepetitionsCV
+    norm <- input$NormsCV
+    maxT <- input$MaxTermsCV
+    g <- chosenGrouping()
+    r <- chosenRaw()
+    e <- chosenExplanatory()
+
+        cNORM::cnorm.cv(preparedData(), repetitions = rep, norms = norm, min = 1, max = maxT, group = g, raw = r, age = e)
+  })
+
+
   rawScorePlot <- eventReactive(c(input$grouping1, input$differences1), {
     type <- 0
     if(input$differences1)
@@ -395,6 +409,10 @@ shinyServer(function(input, output, session) {
     return(modelDensity())
   })
 
+  output$PlotCV <- renderPlot({
+    return(crossValidation())
+  })
+
   output$PlotWL <- renderPlot({
     return(wlPlot())
   })
